==> linuxconf-1.19.src.tar.gz: linuxconf-1.19/modules/apache/apache.pm <==
/* hedit.cc 08/09/1999 00.00.40 */
int HTTPD_USERS::cwrite (void);
int HTTPD_AUTHS::edit (void);
PUBLIC int HTTPD_USERS::edit (void);
PUBLIC int HTTPD_USER::edit (HTTPD_USERS&users);
PUBLIC int HTTPD_CONFIG::perfedit (HTTPD_CONFIG&_httpd);
PUBLIC int HTTPD_CONFIG::modedit (HTTPD_CONFIG&_httpd);
PUBLIC void HTTPD_FEATURES::setdia (DIALOG&dia);
PUBLIC void HTTPD_DOMOPT::setdia (DIALOG&dia, bool advanced);
PUBLIC int HTTPD_CONFIG::editdefaults (void);
/* vhostedit.cc 18/09/1999 10.56.16 */
PUBLIC int HTTPD_DOMAIN::createroot (void);
PUBLIC int HTTPD_DOMAIN::edit (void);
PUBLIC int HTTPD_DOMAINS::write (void);
PUBLIC int HTTPD_DOMAINS::edit (HTTPD_CONFIG&_httpd);
PUBLIC VIRTUAL_COMNG::VIRTUAL_COMNG (DICTIONARY&_dict);
PUBLIC void VIRTUAL_COMNG::setupdia (DIALOG&dia);
PUBLIC int VIRTUAL_COMNG::save (PRIVILEGE *priv);
PUBLIC HTTPD_DOMAIN *HTTPD_CONFIG::locatevhost (const char *vhost);
PUBLIC int VIRTUAL_COMNG::validate (DIALOG&, int &nof);
PUBLIC int VIRTUAL_COMNG::deluser (PRIVILEGE *);
/* _dict.cc 30/09/1997 00.26.22 */
/* apache.cc 18/11/1999 20.08.12 */
PUBLIC MODULE_APACHE::MODULE_APACHE (void);
PUBLIC void MODULE_APACHE::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_APACHE::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC void MODULE_APACHE::usage (SSTRINGS&tb);
PUBLIC int MODULE_APACHE::execmain (int argc, char *argv[]);
/* diredit.cc 08/06/1999 20.49.56 */
PUBLIC void HTTPD_OVERRIDE::setallopt (int val);
PUBLIC HTTPD_OVERRIDE::HTTPD_OVERRIDE (void);
PUBLIC void HTTPD_OVERRIDE::setdia (DIALOG&dia);
PUBLIC int HTTPD_DIRS::f_edit (HTTPD_CONFIG&_httpd);
PUBLIC int HTTPD_DIR::edit (void);
PUBLIC HTTPD_DIR *HTTPD_DIRS::getitem (int no)const;
PUBLIC int HTTPD_DIRS::write (void);
PUBLIC int HTTPD_DIR::f_edit (void);
PUBLIC int HTTPD_DIRS::edit (HTTPD_CONFIG&_httpd);
/* httpd.cc 20/09/1999 16.48.58 */
PUBLIC HTTPD_UNKNOWN *HTTPD_UNKNOWNS::getitem (int no);
PUBLIC HTTPD_DOMAIN *HTTPD_DOMAINS::getitem (int no);
PUBLIC void HTTPD_FEATURES::setallopt (int val);
PUBLIC HTTPD_FEATURES::HTTPD_FEATURES (void);
PUBLIC void HTTPD_OVERRIDE::write (const char *prefix, FILE *fout);
PUBLIC void HTTPD_FEATURES::write (const char *prefix, FILE *fout);
PRIVATE void HTTPD_DIR::init (void);
PUBLIC HTTPD_DIR::HTTPD_DIR (const char *path);
PUBLIC HTTPD_DIR::HTTPD_DIR (void);
PUBLIC void HTTPD_DIR::write (FILE *fout);
PUBLIC void HTTPD_DIRS::write (FILE *fout);
PUBLIC HTTPD_DOMSSL::HTTPD_DOMSSL (void);
PUBLIC void HTTPD_SSL::write (FILE *fout);
PUBLIC void HTTPD_UNKNOWN::write (FILE *fout);
PUBLIC void HTTPD_DOMSSL::write (const char *prefix, FILE *fout);
PUBLIC void HTTPD_DOMOPT::write (const char *prefix, FILE *fout);
PUBLIC HTTPD_UNKNOWN::HTTPD_UNKNOWN (const char *cname,
	 const char *cparam);
PUBLIC HTTPD_UNKNOWN::HTTPD_UNKNOWN (void);
PUBLIC HTTPD_UNKNOWNS::HTTPD_UNKNOWNS (void);
PUBLIC HTTPD_USER *HTTPD_USERS::getitem (int no);
PUBLIC HTTPD_USERS::HTTPD_USERS (void);
PUBLIC HTTPD_USERS *HTTPD_AUTHS::getitem (int no);
PUBLIC HTTPD_DOMAIN::HTTPD_DOMAIN (void);
PUBLIC HTTPD_SSL::HTTPD_SSL (void);
PUBLIC HTTPD_DOMAIN::HTTPD_DOMAIN (const char *domain);
PUBLIC void HTTPD_DOMAIN::write (FILE *fout);
PUBLIC HTTPD_CONFIG::HTTPD_CONFIG (void);
PUBLIC int HTTPD_CONFIG::write (void);
/* internal.cc 28/09/1997 21.36.38 */
PUBLIC APACHE_HELP_FILE::APACHE_HELP_FILE (const char *fname);
/* ssl.cc 29/04/1999 15.33.14 */
PUBLIC int HTTPD_SSL::edit (HTTPD_CONFIG&_httpd);
/* crypt.cc 24/05/1999 17.47.48 */

==> linuxconf-1.20.src.tar.gz: linuxconf-1.20/modules/apache/apache.pm <==
/* _dict.cc 30/09/1997 00.26.22 */
/* apache.cc 04/08/2000 13.06.56 */
PUBLIC MODULE_APACHE::MODULE_APACHE (void);
PUBLIC void MODULE_APACHE::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_APACHE::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC void MODULE_APACHE::usage (SSTRINGS&tb);
PUBLIC int MODULE_APACHE::execmain (int argc, char *argv[]);
/* crypt.cc 24/05/1999 17.47.48 */
/* diredit.cc 08/06/1999 20.49.56 */
PUBLIC void HTTPD_OVERRIDE::setallopt (int val);
PUBLIC HTTPD_OVERRIDE::HTTPD_OVERRIDE (void);
PUBLIC void HTTPD_OVERRIDE::setdia (DIALOG&dia);
PUBLIC int HTTPD_DIRS::f_edit (HTTPD_CONFIG&_httpd);
PUBLIC int HTTPD_DIR::edit (void);
PUBLIC HTTPD_DIR *HTTPD_DIRS::getitem (int no)const;
PUBLIC int HTTPD_DIRS::write (void);
PUBLIC int HTTPD_DIR::f_edit (void);
PUBLIC int HTTPD_DIRS::edit (HTTPD_CONFIG&_httpd);
/* hedit.cc 12/12/1999 22.07.40 */
int HTTPD_USERS::cwrite (void);
int HTTPD_AUTHS::edit (void);
PUBLIC int HTTPD_USERS::edit (void);
PUBLIC int HTTPD_USER::edit (HTTPD_USERS&users);
PUBLIC int HTTPD_CONFIG::perfedit (HTTPD_CONFIG&_httpd);
PUBLIC int HTTPD_CONFIG::modedit (HTTPD_CONFIG&_httpd);
PUBLIC void HTTPD_FEATURES::setdia (DIALOG&dia);
PUBLIC void HTTPD_DOMOPT::setdia (DIALOG&dia, bool advanced);
PUBLIC int HTTPD_CONFIG::editdefaults (void);
/* httpd.cc 07/08/2000 00.20.00 */
PUBLIC HTTPD_UNKNOWN *HTTPD_UNKNOWNS::getitem (int no);
PUBLIC HTTPD_DOMAIN *HTTPD_DOMAINS::getitem (int no);
PUBLIC void HTTPD_FEATURES::setallopt (int val);
PUBLIC HTTPD_FEATURES::HTTPD_FEATURES (void);
PUBLIC void HTTPD_OVERRIDE::write (const char *prefix, FILE_CFG *fout);
PUBLIC void HTTPD_FEATURES::write (const char *prefix, FILE_CFG *fout);
PRIVATE void HTTPD_DIR::init (void);
PUBLIC HTTPD_DIR::HTTPD_DIR (const char *path);
PUBLIC HTTPD_DIR::HTTPD_DIR (void);
PUBLIC void HTTPD_DIR::write (FILE_CFG *fout);
PUBLIC void HTTPD_DIRS::write (FILE_CFG *fout);
PUBLIC HTTPD_DOMSSL::HTTPD_DOMSSL (void);
PUBLIC void HTTPD_SSL::write (FILE_CFG *fout);
PUBLIC void HTTPD_UNKNOWN::write (FILE_CFG *fout);
PUBLIC void HTTPD_DOMSSL::write (const char *prefix, FILE_CFG *fout);
PUBLIC void HTTPD_DOMOPT::write (const char *prefix, FILE_CFG *fout);
PUBLIC HTTPD_UNKNOWN::HTTPD_UNKNOWN (const char *cname,
	 const char *cparam);
PUBLIC HTTPD_UNKNOWN::HTTPD_UNKNOWN (void);
PUBLIC HTTPD_UNKNOWNS::HTTPD_UNKNOWNS (void);
PUBLIC HTTPD_USER *HTTPD_USERS::getitem (int no);
PUBLIC HTTPD_USERS::HTTPD_USERS (void);
PUBLIC HTTPD_USERS *HTTPD_AUTHS::getitem (int no);
PUBLIC HTTPD_DOMAIN::HTTPD_DOMAIN (void);
PUBLIC HTTPD_SSL::HTTPD_SSL (void);
PUBLIC HTTPD_DOMAIN::HTTPD_DOMAIN (const char *domain);
PUBLIC void HTTPD_DOMAIN::write (FILE_CFG *fout);
PUBLIC HTTPD_CONFIG::HTTPD_CONFIG (void);
PUBLIC int HTTPD_CONFIG::write (void);
/* internal.cc 28/09/1997 21.36.38 */
PUBLIC APACHE_HELP_FILE::APACHE_HELP_FILE (const char *fname);
/* ssl.cc 29/04/1999 15.33.14 */
PUBLIC int HTTPD_SSL::edit (HTTPD_CONFIG&_httpd);
/* vhostedit.cc 06/01/2000 11.49.18 */
PUBLIC int HTTPD_DOMAIN::createroot (void);
PUBLIC int HTTPD_DOMAIN::edit (void);
PUBLIC int HTTPD_DOMAINS::write (void);
PUBLIC int HTTPD_DOMAINS::edit (HTTPD_CONFIG&_httpd);
PUBLIC VIRTUAL_COMNG::VIRTUAL_COMNG (DICTIONARY&_dict);
PUBLIC void VIRTUAL_COMNG::setupdia (DIALOG&dia);
PUBLIC int VIRTUAL_COMNG::save (PRIVILEGE *priv);
PUBLIC HTTPD_DOMAIN *HTTPD_CONFIG::locatevhost (const char *vhost);
PUBLIC int VIRTUAL_COMNG::validate (DIALOG&, int &nof);
PUBLIC int VIRTUAL_COMNG::deluser (PRIVILEGE *);
